@@ -14,7 +14,6 @@ from scipy.special import expi
 from scipy.special import expn
 
 import sympy as sp
-# import time
 
 try:
     # if symengine is available, use it to perform series-expansions
@@ -26,7 +25,8 @@ except ImportError:
 
 
 class RT1(object):
-    """ Main class to perform RT-simulations
+    """
+    Main class to perform RT-simulations
 
     Parameters
     ----------
@@ -76,9 +76,9 @@ class RT1(object):
             t_0, t_ex, p_0, p_ex
 
         - 'f' indicates that the angle is treated 'fixed'
-        (i.e. as a numerical constant)
+          (i.e. as a numerical constant)
         - 'v' indicates that the angle is treated 'variable'
-        (i.e. as a sympy-variable)
+          (i.e. as a sympy-variable)
         - Passing  geometry = 'mono'  indicates a monstatic geometry
           (i.e.:  t_ex = t_0, p_ex = p_0 + pi)
           If monostatic geometry is used, the input-values of t_ex and p_ex
@@ -95,19 +95,17 @@ class RT1(object):
     param_dict : dict (default = {})
                  a dictionary to assign numerical values to sympy.Symbols
                  appearing in the definitions of V and SRF.
-    lambda_backend : str (default = 'cse')
+    lambda_backend : str (default = 'symengine' if possible, else 'sympy')
                      indicator to select the module that shall be used
                      to compile a function for numerical evaluation of the
                      fn-coefficients.
 
-                     TODO(update this) possible values are:
+                     possible values are:
                          - 'sympy' :  sympy.lambdify is used to compile
                            the _fnevals function
                          - 'symengine' : symengine.LambdifyCSE is used to
                            compile the _fnevals function. This results in
                            considerable speedup for long fn-coefficients
-                         - 'cse' : sympy.lambdify is used together with
-                           sympy.cse to generate a fast evaluation-function
     int_Q : bool (default = True)
             indicator whether the interaction-term should be calculated or not
     verbosity : int
@@ -180,26 +178,6 @@ class RT1(object):
                                                  'must be greater than 0')
 
 
-# TODO  fix asserts to allow symbolic parameters
-        # check if all parameters have been provided (and also if no
-        # unused parameter has been specified)
-
-#        refset = set(sp.var(('theta_0', 'phi_0', 'theta_ex', 'phi_ex') +
-#                            tuple(map(str, self.param_dict.keys()))))
-#
-#        funcset = self.V._func.free_symbols | self.SRF._func.free_symbols
-#
-#        if refset <= funcset:
-#            errdict = ' in the definition of V and SRF'
-#        elif refset >= funcset:
-#            errdict = ' in the definition of param_dict'
-#        else:
-#            errdict = ' in the definition of V, SRF and param_dict'
-#
-#        assert (funcset == refset), ('false parameter-specification, please ' +
-#                                     'check assignment of the parameters '
-#                                     + str(refset ^ funcset) + errdict)
-
     def __getstate__(self):
         # this is required since functions created by
         # symengine are currently not pickleable!
@@ -254,10 +232,18 @@ class RT1(object):
         '''
         function to set print output based on verbosity level v.
         possible values for v:
+
             - 0 : print nothing
             - 1 : print some infos during runtime
             - 2 : print more
             - >=3 : print all
+
+        Parameters
+        ----------
+        v : int
+            the verbosity.
+        msg : str
+            the message to be printed.
         '''
         if self.verbosity >= v:
             print(msg)
@@ -717,7 +703,7 @@ class RT1(object):
         Numerical evaluation of the slope (dI_s/dt_0) of the
         (!monostatic!) surface-contribution
 
-        Parameter
+        Parameters
         ----------
         dB : bool (default = False)
              indicator if the derivative is calculated for
@@ -777,7 +763,7 @@ class RT1(object):
         Numerical evaluation of the curvature (d^2I_s/dt_0^2)
         of the (!monostatic!) surface-contribution
 
-        Parameter
+        Parameters
         ----------
         dB : bool (default = False)
              indicator if the derivative is calculated for
@@ -873,7 +859,7 @@ class RT1(object):
         Numerical evaluation of the slope (dI_v/dt_0) of the
         (!monostatic!) volume-contribution
 
-        Parameter
+        Parameters
         ----------
         dB : bool (default = False)
              indicator if the derivative is calculated for
@@ -929,7 +915,7 @@ class RT1(object):
         Numerical evaluation of the curvature (d^2I_s/dt_0^2)
         of the (!monostatic!) volume-contribution
 
-        Parameter
+        Parameters
         ----------
         dB : bool (default = False)
              indicator if the derivative is calculated for
@@ -977,21 +963,6 @@ class RT1(object):
                            ) * p_curv )
 
 
-
-#
-#        I_curv = (1. - self.bsf) * self.I0 * self.V.omega / 2. * (
-#                np.exp(-(2 * self.V.tau / self._mu_0)) * (
-#                        4. * self.V.tau * np.sin(self.t_0) / self._mu_0**2 * p_slope
-#                        +
-#                        (1. + 2. * np.sin(self.t_0)**2 / self._mu_0**2
-#                         - 2. * self.V.tau * np.sin(self.t_0)**2 / self._mu_0**3) *
-#                         2. * self.V.tau / self._mu_0 * p_val
-#                        )
-#                + (1. - np.exp(-(2 * self.V.tau / self._mu_0))) * p_curv
-#                )
-
-
-
         if sig0 is False and dB is False:
             return I_curv
         else:
@@ -1015,7 +986,7 @@ class RT1(object):
         numerical value of the (!monostatic!) slope of total
         contribution (surface + volume)
 
-        Parameter
+        Parameters
         ----------
         dB : bool (default = False)
              indicator if the derivative is calculated for
@@ -1053,7 +1024,7 @@ class RT1(object):
         numerical value of the (!monostatic!) curvature of
         total contribution (surface + volume)
 
-        Parameter
+        Parameters
         ----------
         dB : bool (default = False)
              indicator if the derivative is calculated for
@@ -1429,12 +1400,12 @@ class RT1(object):
         Generation of a function that evaluates the derivative of the
         surface-contribution with respect to the provided key
 
-        Parameters:
+        Parameters
         ------------
         key : string
 
 
-        Returns:
+        Returns
         --------
         - : array_like(float)
             Numerical value of dIsurf/dkey for the given set of parameters
@@ -1477,7 +1448,7 @@ class RT1(object):
             The contribution of the interaction-term is currently
             not considered in the calculation of the jacobian!
 
-        Parameters:
+        Parameters
         -------------
         dB : boolean (default = False)
              Indicator whether linear or dB units are used.
@@ -1502,7 +1473,7 @@ class RT1(object):
                      any string corresponding to a sympy.Symbol used in the
                      definition of V or SRF
 
-        Returns:
+        Returns
         ---------
         jac : array-like(float)
               The jacobian of the total backscatter with respect to
